@@ -55,8 +55,9 @@ setColor( PyObject* self, PyObject* args )
 
     getSurfaceAttrs(py_surface, &w, &h, &format, &surface);
 
-    if(!RGBAFromColorObj (py_color, color))
-        return Py_None;
+    if(!RGBAFromColorObj (py_color, color)){
+        Py_INCREF(Py_None);return Py_None;
+    }
 
     for( y = 0; y < h; y ++ ){
         for( x = 0; x < w; x ++ ){
@@ -66,6 +67,7 @@ setColor( PyObject* self, PyObject* args )
         }
     }
 
+    Py_INCREF(Py_None);
     return Py_None;
 }
 
@@ -117,7 +119,7 @@ setAlpha( PyObject* self, PyObject* args )
         }
     }
 
-    return Py_None;
+    Py_INCREF(Py_None);return Py_None;
 
 }
 
@@ -165,7 +167,7 @@ greyscale( PyObject* self, PyObject* args )
         }
     }
 
-    return Py_None;
+    Py_INCREF(Py_None);return Py_None;
 }
 
 
@@ -178,7 +180,6 @@ invert( PyObject* self, PyObject* args )
     PyObject* py_surface = NULL;
     SDL_Surface *surface;
     int w,h,pxcnt = 0;
-    Uint32 pixel;
     SDL_PixelFormat *format = NULL;
     Uint8 r,g,b,a;
 
@@ -190,12 +191,73 @@ invert( PyObject* self, PyObject* args )
     pxcnt = w * h;
 
     while( pxcnt-- ){
-        pixel = getPixelN(surface, pxcnt);
-        SDL_GetRGBA( pixel, format, &r, &g, &b, &a );
-        pixel = SDL_MapRGBA( format, 255-r, 255-g, 255-b, a );
-        setPixelN(surface, pxcnt, pixel);
+        getPixelN_RGBA(surface, pxcnt, &r, &g, &b, &a);
+        setPixelN_RGBA(surface, pxcnt, 255-r, 255-g, 255-b, a);
     }
-    return Py_None;
+    Py_INCREF(Py_None);return Py_None;
+}
+
+
+/*
+    Adjust surface contrast
+*/
+static PyObject*
+contrast( PyObject* self, PyObject* args )
+{
+    PyObject* py_surface = NULL;
+    SDL_Surface *surface;
+    int w,h,pxcnt = 0,cvalue = 0;
+    float factor = 0;
+    SDL_PixelFormat *format = NULL;
+    Uint8 r,g,b,a;
+
+    PY_PARSEARGS_BEGIN
+        "Oi", &py_surface, &cvalue
+    PY_PARSEARGS_END
+
+    getSurfaceAttrs(py_surface, &w, &h, &format, &surface);
+    pxcnt = w * h;
+    
+    factor = (259 * ((float)cvalue + 255)) / (255 * (259 - cvalue));
+
+    while( pxcnt-- ){
+        getPixelN_RGBA(surface, pxcnt, &r, &g, &b, &a);
+        r = clampUint8(factor * (r - 128) + 128);
+        g = clampUint8(factor * (g - 128) + 128);
+        b = clampUint8(factor * (b - 128) + 128);
+        setPixelN_RGBA(surface, pxcnt, r, g, b, a);
+    }
+    Py_INCREF(Py_None);return Py_None;
+}
+
+/*
+    Adjust surface brightness
+*/
+static PyObject*
+brightness( PyObject* self, PyObject* args )
+{
+    PyObject* py_surface = NULL;
+    SDL_Surface *surface;
+    int w,h,pxcnt = 0,bvalue = 0;
+    float factor = 0;
+    SDL_PixelFormat *format = NULL;
+    Uint8 r,g,b,a;
+
+    PY_PARSEARGS_BEGIN
+        "Oi", &py_surface, &bvalue
+    PY_PARSEARGS_END
+
+    getSurfaceAttrs(py_surface, &w, &h, &format, &surface);
+    pxcnt = w * h;
+    
+    while( pxcnt-- ){
+        getPixelN_RGBA(surface, pxcnt, &r, &g, &b, &a);
+        r = clampUint8(r + bvalue);
+        g = clampUint8(g + bvalue);
+        b = clampUint8(b + bvalue);
+        setPixelN_RGBA(surface, pxcnt, r, g, b, a);
+    }
+    Py_INCREF(Py_None);return Py_None;
 }
 
 /*
@@ -247,7 +309,7 @@ hue( PyObject* self, PyObject* args )
         pixel = SDL_MapRGBA( format, r, g, b, a );
         setPixelN(surface, pxcnt, pixel);
     }
-    return Py_None;
+    Py_INCREF(Py_None);return Py_None;
 }
 
 /*
@@ -299,7 +361,7 @@ saturation( PyObject* self, PyObject* args )
         pixel = SDL_MapRGBA( format, r, g, b, a );
         setPixelN(surface, pxcnt, pixel);
     }
-    return Py_None;
+    Py_INCREF(Py_None);return Py_None;
 }
 
 /*
@@ -351,7 +413,7 @@ value( PyObject* self, PyObject* args )
         pixel = SDL_MapRGBA( format, r, g, b, a );
         setPixelN(surface, pxcnt, pixel);
     }
-    return Py_None;
+    Py_INCREF(Py_None);return Py_None;
 }
 
 static PyObject*
@@ -396,7 +458,7 @@ lightness( PyObject* self, PyObject* args )
         setPixelN(surface, pxcnt, pixel);
     }
 
-    return Py_None;
+    Py_INCREF(Py_None);return Py_None;
 }
 
 /* Color multiply */
@@ -433,7 +495,7 @@ multiply( PyObject* self, PyObject* args )
         setPixelN_RGBA(surface, pxcnt, r, g, b, a);
     }
 
-    return Py_None;
+    Py_INCREF(Py_None);return Py_None;
 }
 
 
@@ -558,7 +620,7 @@ alphaMask( PyObject* self, PyObject* args )
                 if(tmp_a > 0){/* if mask alpha > 0 then set original alpha */
                     tmp_a = a;
                 }
-            } else {
+           } else {
                 tmp_a = 255;
             }
 
@@ -581,6 +643,8 @@ static PyMethodDef ColorMethods[] = {
     {"lightness", lightness, METH_VARARGS, "Lightness"},
     {"multiply", multiply, METH_VARARGS, "Color multiply"},
 
+    {"brightness", brightness, METH_VARARGS, "Surface brightness"},
+    {"contrast", contrast, METH_VARARGS, "Surface contrast"},
     {"invert", invert, METH_VARARGS, "Invert colors of surface"},
     {"greyscale", greyscale, METH_VARARGS, "Create greyscale surface"},
     {"colorize", colorize, METH_VARARGS, "Change hue of surface"},
