@@ -64,7 +64,6 @@ _shadow( SDL_Surface *surface, int radius, float opacity, int w, int h, int rw,
     for( y = 0; y < h; y ++ ){
         for( x = 0; x < w; x ++ ){
             getPixel_RGBA(surface, x, y, &r, &g, &b, &a );
-            if(a == 0) continue;
             if(opacity < 1){
                 a = (Uint8) (((double)a) * opacity);
             }
@@ -243,7 +242,7 @@ noise( PyObject* self, PyObject* args )
         if(cnt < 0) break;
     }
 
-    return Py_None;
+    Py_INCREF(Py_None);return Py_None;
 }
 
 
@@ -287,7 +286,7 @@ noiseBlur( PyObject* self, PyObject* args )
         }
     }
 
-    return Py_None;
+    Py_INCREF(Py_None);return Py_None;
 }
 
 
@@ -330,7 +329,7 @@ scratch( PyObject* self, PyObject* args )
     }
 
     SDL_FreeSurface(surface_copy);
-    return Py_None;
+    Py_INCREF(Py_None);return Py_None;
 }
 
 /*
@@ -369,7 +368,7 @@ pixelize( PyObject* self, PyObject* args )
         }
     }
 
-    return Py_None;
+    Py_INCREF(Py_None);return Py_None;
 }
 
 
@@ -393,11 +392,13 @@ gradient( PyObject* self, PyObject* args )
         "(ii)OO|bf", &w, &h, &py_fcolor, &py_tcolor, &vertical, &ratio
     PY_PARSEARGS_END
 
-    if(!RGBAFromColorObj (py_fcolor, fcolor))
-        return Py_None;
+    if(!RGBAFromColorObj (py_fcolor, fcolor)){
+        Py_INCREF(Py_None);return Py_None;
+    }
 
-    if(!RGBAFromColorObj (py_tcolor, tcolor))
-        return Py_None;
+    if(!RGBAFromColorObj (py_tcolor, tcolor)){
+        Py_INCREF(Py_None);return Py_None;
+    }
 
     surface = _gradient(w, h, fcolor, tcolor, vertical, ratio);
 
@@ -425,7 +426,9 @@ shadow(PyObject* self, PyObject* args)
         "OO|ibf", &py_surface, &py_color, &radius, &resized, &opacity
     PY_PARSEARGS_END
 
-    if(!RGBAFromColorObj (py_color, color)) return Py_None;
+    if(!RGBAFromColorObj (py_color, color)) {
+        Py_INCREF(Py_None);return Py_None;
+    }
     getSurfaceAttrs(py_surface, &w, &h, &format, &surface);
 
     /* only 32bit surfaces are supported */
@@ -479,7 +482,7 @@ blur(PyObject* self, PyObject* args)
 
     SDL_FreeSurface( temp_surface );
 
-    return Py_None;
+    Py_INCREF(Py_None);return Py_None;
 }
 
 /*
@@ -509,7 +512,7 @@ hvBlur(PyObject* self, PyObject* args)
 
     SDL_FreeSurface(copy_surface);
 
-    return Py_None;
+    Py_INCREF(Py_None);return Py_None;
 }
 
 /*
@@ -566,7 +569,7 @@ ripple(PyObject* self, PyObject* args)
 
     SDL_FreeSurface( copy_surface );
 
-    return Py_None;
+    Py_INCREF(Py_None);return Py_None;
 }
 
 
