@@ -40,7 +40,7 @@
 
 /* Parsing PyArgs */
 #define PY_PARSEARGS_BEGIN if( !PyArg_ParseTuple(args,
-#define PY_PARSEARGS_END ) ) return Py_None;
+#define PY_PARSEARGS_END ) ) {Py_INCREF(Py_None);return Py_None;}
 
 #define clampUint8(N)  ( (N < 0) ? 0 : ((N > 255) ? 255 : N) )
 #define clampValue(N,NMIN,NMAX)  ( (N < NMIN)?NMIN:((N > NMAX)?NMAX:N) )
